django-salesforce contributors
------------------------------

* Phil Christensen <https://github.com/philchristensen>
* Steve Bussetti <https://github.com/sbussetti>
* Reggie Dugard <https://github.com/reggied>